@@ -107,7 +107,7 @@ class Tier(object):
         return plot
 
     def get_point(self, by_target, by, strict=True, point_type=None):
-        """Get Point of the Tier with chosen method. \n If `strict` set to False, get the closest Point object to the target. If `point_type` set to `larger`, find the closest larger Point; If `point_type` set to `smaller`, find the closest smaller Point.\nSee `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
+        """Get Point of the Tier with chosen method. \n If `strict` set to False, get the closest Point object to the target. If `point_type` set to \'larger\', find the closest larger Point; If `point_type` set to \'smaller\', find the closest smaller Point.\nSee `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -132,7 +132,7 @@ class Tier(object):
                     points = [point for point in points if point.time <= by_target]
                 else:
                     raise Exception(
-                        '`point_type` can only by one of {`larger`, `smaller`, None}.'
+                        '`point_type` can only by one of {\'larger\', \'smaller\', None}.'
                     )
 
                 points.sort(key=lambda point: abs(point.time - by_target))
